@@ -376,6 +376,15 @@ public:
 		}
 		maxFutureSupply = maxSupply;
 	}
+
+	void setState(vector<int> myState) {
+		state = myState;
+	}
+
+	void setGoalState(vector<int> myGoalState) {
+		goalState = myGoalState;
+	}
+
 	void initEntityList() {
 		entityList.push_back(loadEntity(n.dummy, 0, 0, true));
 		entityList.push_back(loadEntity(n.nexus, 0, 0, true));
@@ -756,6 +765,8 @@ PYBIND11_MODULE(probotest1, m) {
 		.def("getTimeAllComplete", &ProtossMacroEnv::getTimeAllComplete)
 		.def("getEssentialActions", &ProtossMacroEnv::getEssentialActions)
 		.def("isDone",&ProtossMacroEnv::isDone)
+		.def("setGoalState", &ProtossMacroEnv::setGoalState)
+		.def("setState", &ProtossMacroEnv::setState)
         .def_readwrite("minerals", &ProtossMacroEnv::minerals)
 		.def_readwrite("gas", &ProtossMacroEnv::gas)
 		.def_readwrite("time", &ProtossMacroEnv::time)
